pub enum OnConflictTarget {
Identifiers(Vec<OnConflictIdentifier>),
Constraint(String),
}Expand description
Represents ON CONFLICT (upsert) targets
Targets can be a list of columns or expressions, even mixed, or just a single constraint name.
Variants
Identifiers(Vec<OnConflictIdentifier>)
List of column names or expressions
Constraint(String)
A constraint name