pub enum HasManyModel<E>where
E: EntityTrait,{
NotSet,
Replace(Vec<<E as EntityTrait>::ActiveModelEx>),
Append(Vec<<E as EntityTrait>::ActiveModelEx>),
}Expand description
Container for 1-N or M-N related Models
Variants
NotSet
Unspecified value, do nothing
Replace(Vec<<E as EntityTrait>::ActiveModelEx>)
Replace all items with this value set; delete leftovers
Append(Vec<<E as EntityTrait>::ActiveModelEx>)
Add new items to this has many relation; do not delete
Implementations
Sourceimpl<E> HasManyModel<E>where
E: EntityTrait,
impl<E> HasManyModel<E>where
E: EntityTrait,
Sourcepub fn take(&mut self) -> HasManyModel<E>
pub fn take(&mut self) -> HasManyModel<E>
Take ownership of the models, leaving NotSet in place
Sourcepub fn as_slice(&self) -> &[<E as EntityTrait>::ActiveModelEx]
pub fn as_slice(&self) -> &[<E as EntityTrait>::ActiveModelEx]
Borrow models as slice
Sourcepub fn as_mut_vec(&mut self) -> &mut Vec<<E as EntityTrait>::ActiveModelEx>
pub fn as_mut_vec(&mut self) -> &mut Vec<<E as EntityTrait>::ActiveModelEx>
Get a mutable vec. If self is NotSet, convert to append.
Sourcepub fn into_vec(self) -> Vec<<E as EntityTrait>::ActiveModelEx>
pub fn into_vec(self) -> Vec<<E as EntityTrait>::ActiveModelEx>
Consume self as vector
Sourcepub fn empty_holder(&self) -> HasManyModel<E>
pub fn empty_holder(&self) -> HasManyModel<E>
Returns an empty container of self
Sourcepub fn push<AM>(&mut self, model: AM) -> &mut HasManyModel<E>
pub fn push<AM>(&mut self, model: AM) -> &mut HasManyModel<E>
Push an item to self
Sourcepub fn append<AM>(&mut self, model: AM) -> &mut HasManyModel<E>
pub fn append<AM>(&mut self, model: AM) -> &mut HasManyModel<E>
Push an item to self, but convert Replace to Append
Sourcepub fn replace_all<I>(&mut self, models: I) -> &mut HasManyModel<E>
pub fn replace_all<I>(&mut self, models: I) -> &mut HasManyModel<E>
Replace all items in this set
Sourcepub fn convert_to_append(&mut self) -> &mut HasManyModel<E>
pub fn convert_to_append(&mut self) -> &mut HasManyModel<E>
Convert self to Append, if set
Sourcepub fn is_replace(&self) -> bool
pub fn is_replace(&self) -> bool
If self is Replace
Sourcepub fn is_changed(&self) -> bool
pub fn is_changed(&self) -> bool
Return true if self is Replace or any containing model is changed
Sourcepub fn find(&self, model: &<E as EntityTrait>::Model) -> bool
pub fn find(&self, model: &<E as EntityTrait>::Model) -> bool
Find within the models by primary key, return true if found
Sourcepub fn try_into_model(self) -> Result<HasMany<E>, DbErr>
pub fn try_into_model(self) -> Result<HasMany<E>, DbErr>
Convert this back to a ModelEx container