pub struct SqliteStatement { /* private fields */ }Trait Implementations
Sourceimpl Clone for SqliteStatement
impl Clone for SqliteStatement
Sourcefn clone(&self) -> SqliteStatement
fn clone(&self) -> SqliteStatement
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ColumnIndex<SqliteStatement> for &str
impl ColumnIndex<SqliteStatement> for &str
Sourcefn index(&self, statement: &SqliteStatement) -> Result<usize, Error>
fn index(&self, statement: &SqliteStatement) -> Result<usize, Error>
Returns a valid positional index into the row or statement,
ColumnIndexOutOfBounds, or,
ColumnNotFound.Sourceimpl ColumnIndex<SqliteStatement> for usize
impl ColumnIndex<SqliteStatement> for usize
Sourcefn index(&self, statement: &SqliteStatement) -> Result<usize, Error>
fn index(&self, statement: &SqliteStatement) -> Result<usize, Error>
Returns a valid positional index into the row or statement,
ColumnIndexOutOfBounds, or,
ColumnNotFound.Sourceimpl Debug for SqliteStatement
impl Debug for SqliteStatement
Sourceimpl Statement for SqliteStatement
impl Statement for SqliteStatement
type Database = Sqlite
Sourcefn parameters(&self) -> Option<Either<&[SqliteTypeInfo], usize>>
fn parameters(&self) -> Option<Either<&[SqliteTypeInfo], usize>>
Get the expected parameters for this statement. Read more
Sourcefn columns(&self) -> &[SqliteColumn]
fn columns(&self) -> &[SqliteColumn]
Get the columns expected to be returned by executing this statement.
fn query( &self, ) -> Query<'_, <SqliteStatement as Statement>::Database, SqliteArguments>
fn query_with<A>( &self, arguments: A, ) -> Query<'_, <SqliteStatement as Statement>::Database, A>
fn query_as<O>( &self, ) -> QueryAs<'_, <SqliteStatement as Statement>::Database, O, <<SqliteStatement as Statement>::Database as Database>::Arguments>
fn query_as_with<'s, O, A>(
&'s self,
arguments: A,
) -> QueryAs<'s, <SqliteStatement as Statement>::Database, O, A>where
O: for<'r> FromRow<'r, <<SqliteStatement as Statement>::Database as Database>::Row>,
A: IntoArguments<<SqliteStatement as Statement>::Database>,
fn query_scalar<O>( &self, ) -> QueryScalar<'_, <SqliteStatement as Statement>::Database, O, <<SqliteStatement as Statement>::Database as Database>::Arguments>
fn query_scalar_with<'s, O, A>(
&'s self,
arguments: A,
) -> QueryScalar<'s, <SqliteStatement as Statement>::Database, O, A>where
(O,): for<'r> FromRow<'r, <<SqliteStatement as Statement>::Database as Database>::Row>,
A: IntoArguments<<SqliteStatement as Statement>::Database>,
Sourcefn column<I>(&self, index: I) -> &<Self::Database as Database>::Columnwhere
I: ColumnIndex<Self>,
fn column<I>(&self, index: I) -> &<Self::Database as Database>::Columnwhere
I: ColumnIndex<Self>,
Gets the column information at
index. Read moreSourcefn try_column<I>(
&self,
index: I,
) -> Result<&<Self::Database as Database>::Column, Error>where
I: ColumnIndex<Self>,
fn try_column<I>(
&self,
index: I,
) -> Result<&<Self::Database as Database>::Column, Error>where
I: ColumnIndex<Self>,
Gets the column information at
index or a ColumnIndexOutOfBounds error if out of bounds.Auto Trait Implementations
impl Freeze for SqliteStatement
impl RefUnwindSafe for SqliteStatement
impl Send for SqliteStatement
impl Sync for SqliteStatement
impl Unpin for SqliteStatement
impl UnsafeUnpin for SqliteStatement
impl UnwindSafe for SqliteStatement