pub struct UpdateOne<A>(/* private fields */)
where
A: ActiveModelTrait;Expand description
A request to update an ActiveModel.
The primary key must be set.
Otherwise, it’s impossible to generate the SQL condition and find the record.
In that case, exec will return an error and not send any queries to the database.
If you want to use QueryTrait and access the generated SQL query,
you need to convert into ValidatedUpdateOne first.
Implementations
Sourceimpl<A> UpdateOne<A>where
A: ActiveModelTrait,
impl<A> UpdateOne<A>where
A: ActiveModelTrait,
Sourcepub async fn exec<C>(
self,
db: &C,
) -> Result<<<A as ActiveModelTrait>::Entity as EntityTrait>::Model, DbErr>where
<<A as ActiveModelTrait>::Entity as EntityTrait>::Model: IntoActiveModel<A>,
C: ConnectionTrait,
pub async fn exec<C>(
self,
db: &C,
) -> Result<<<A as ActiveModelTrait>::Entity as EntityTrait>::Model, DbErr>where
<<A as ActiveModelTrait>::Entity as EntityTrait>::Model: IntoActiveModel<A>,
C: ConnectionTrait,
Execute an UPDATE operation on an ActiveModel
Sourceimpl<A> UpdateOne<A>where
A: ActiveModelTrait,
impl<A> UpdateOne<A>where
A: ActiveModelTrait,
Sourcepub fn validate(self) -> Result<ValidatedUpdateOne<A>, DbErr>
pub fn validate(self) -> Result<ValidatedUpdateOne<A>, DbErr>
Check whether the primary key is set and we can proceed with the operation.