pub struct Enum {
pub type_name: Arc<str>,
pub value: Cow<'static, str>,
}Fields
type_name: Arc<str>value: Cow<'static, str>Trait Implementations
Sourceimpl ActiveEnumValue for Enum
impl ActiveEnumValue for Enum
Sourcefn try_get_vec_by<I>(
_res: &QueryResult,
_index: I,
) -> Result<Vec<Enum>, TryGetError>where
I: ColIdx,
fn try_get_vec_by<I>(
_res: &QueryResult,
_index: I,
) -> Result<Vec<Enum>, TryGetError>where
I: ColIdx,
For getting an array of enum. Postgres only
impl Eq for Enum
impl StructuralPartialEq for Enum
Sourceimpl TryGetable for Enum
impl TryGetable for Enum
Sourcefn try_get_by<I>(res: &QueryResult, idx: I) -> Result<Enum, TryGetError>where
I: ColIdx,
fn try_get_by<I>(res: &QueryResult, idx: I) -> Result<Enum, TryGetError>where
I: ColIdx,
Get a value from the query result with an ColIdx
Sourcefn try_get(res: &QueryResult, pre: &str, col: &str) -> Result<Self, TryGetError>
fn try_get(res: &QueryResult, pre: &str, col: &str) -> Result<Self, TryGetError>
Get a value from the query result with prefixed column name
Sourcefn try_get_by_index(
res: &QueryResult,
index: usize,
) -> Result<Self, TryGetError>
fn try_get_by_index( res: &QueryResult, index: usize, ) -> Result<Self, TryGetError>
Get a value from the query result based on the order in the select expressions
Sourceimpl ValueType for Enum
impl ValueType for Enum
fn try_from(v: Value) -> Result<Enum, ValueTypeErr>
fn type_name() -> String
fn array_type() -> ArrayType
fn column_type() -> ColumnType
fn unwrap(v: Value) -> Self
fn expect(v: Value, msg: &str) -> Self
fn is_option() -> bool
fn enum_type_name() -> Option<&'static str>