pub struct UpdateStatement { /* private fields */ }Expand description
Update existing rows in the table
Examples
use sea_query::{tests_cfg::*, *};
let query = Query::update()
.table(Glyph::Table)
.values([(Glyph::Aspect, 1.23.into()), (Glyph::Image, "123".into())])
.and_where(Expr::col(Glyph::Id).eq(1))
.to_owned();
assert_eq!(
query.to_string(MysqlQueryBuilder),
r#"UPDATE `glyph` SET `aspect` = 1.23, `image` = '123' WHERE `id` = 1"#
);
assert_eq!(
query.to_string(PostgresQueryBuilder),
r#"UPDATE "glyph" SET "aspect" = 1.23, "image" = '123' WHERE "id" = 1"#
);
assert_eq!(
query.to_string(SqliteQueryBuilder),
r#"UPDATE "glyph" SET "aspect" = 1.23, "image" = '123' WHERE "id" = 1"#
);Implementations
Sourceimpl UpdateStatement
impl UpdateStatement
Sourcepub fn new() -> UpdateStatement
pub fn new() -> UpdateStatement
Construct a new UpdateStatement
pub fn take(&mut self) -> UpdateStatement
Sourcepub fn table<T>(&mut self, tbl_ref: T) -> &mut UpdateStatementwhere
T: IntoTableRef,
pub fn table<T>(&mut self, tbl_ref: T) -> &mut UpdateStatementwhere
T: IntoTableRef,
Sourcepub fn from<R>(&mut self, tbl_ref: R) -> &mut UpdateStatementwhere
R: IntoTableRef,
pub fn from<R>(&mut self, tbl_ref: R) -> &mut UpdateStatementwhere
R: IntoTableRef,
Update using data from another table (UPDATE .. FROM ..).
MySQL Notes
MySQL doesn’t support the UPDATE FROM syntax. And the current implementation attempt to tranform it to the UPDATE JOIN syntax, which only works for one join target.
Examples
use sea_query::{audit::*, tests_cfg::*, *};
let query = Query::update()
.table(Glyph::Table)
.value(Glyph::Tokens, Expr::column((Char::Table, Char::Character)))
.from(Char::Table)
.cond_where(
Expr::col((Glyph::Table, Glyph::Image))
.eq(Expr::col((Char::Table, Char::UserData))),
)
.to_owned();
assert_eq!(
query.to_string(MysqlQueryBuilder),
"UPDATE `glyph` JOIN `character` ON `glyph`.`image` = `character`.`user_data` SET `glyph`.`tokens` = `character`.`character`"
);
assert_eq!(
query.to_string(PostgresQueryBuilder),
r#"UPDATE "glyph" SET "tokens" = "character"."character" FROM "character" WHERE "glyph"."image" = "character"."user_data""#
);
assert_eq!(
query.to_string(SqliteQueryBuilder),
r#"UPDATE "glyph" SET "tokens" = "character"."character" FROM "character" WHERE "glyph"."image" = "character"."user_data""#
);
assert_eq!(
query.audit().unwrap().updated_tables(),
[Glyph::Table.into_iden()]
);
assert_eq!(
query.audit().unwrap().selected_tables(),
[Char::Table.into_iden()]
);Sourcepub fn values<T, I>(&mut self, values: I) -> &mut UpdateStatement
pub fn values<T, I>(&mut self, values: I) -> &mut UpdateStatement
Update column values. To set multiple column-value pairs at once.
Examples
use sea_query::{audit::*, tests_cfg::*, *};
let query = Query::update()
.table(Glyph::Table)
.values([
(Glyph::Aspect, 2.1345.into()),
(Glyph::Image, "235m".into()),
])
.to_owned();
assert_eq!(
query.to_string(MysqlQueryBuilder),
r#"UPDATE `glyph` SET `aspect` = 2.1345, `image` = '235m'"#
);
assert_eq!(
query.to_string(PostgresQueryBuilder),
r#"UPDATE "glyph" SET "aspect" = 2.1345, "image" = '235m'"#
);
assert_eq!(
query.to_string(SqliteQueryBuilder),
r#"UPDATE "glyph" SET "aspect" = 2.1345, "image" = '235m'"#
);
assert_eq!(
query.audit().unwrap().updated_tables(),
[Glyph::Table.into_iden()]
);
assert_eq!(query.audit().unwrap().selected_tables(), []);Sourcepub fn value<C, T>(&mut self, col: C, value: T) -> &mut UpdateStatement
pub fn value<C, T>(&mut self, col: C, value: T) -> &mut UpdateStatement
Update column value by Expr.
Examples
use sea_query::{*, tests_cfg::*};
let query = Query::update()
.table(Glyph::Table)
.value(Glyph::Aspect, Expr::cust("60 * 24 * 24"))
.values([
(Glyph::Image, "24B0E11951B03B07F8300FD003983F03F0780060".into()),
])
.to_owned();
assert_eq!(
query.to_string(MysqlQueryBuilder),
r#"UPDATE `glyph` SET `aspect` = 60 * 24 * 24, `image` = '24B0E11951B03B07F8300FD003983F03F0780060'"#
);
assert_eq!(
query.to_string(PostgresQueryBuilder),
r#"UPDATE "glyph" SET "aspect" = 60 * 24 * 24, "image" = '24B0E11951B03B07F8300FD003983F03F0780060'"#
);
assert_eq!(
query.to_string(SqliteQueryBuilder),
r#"UPDATE "glyph" SET "aspect" = 60 * 24 * 24, "image" = '24B0E11951B03B07F8300FD003983F03F0780060'"#
);
let query = Query::update()
.table(Glyph::Table)
.value(Glyph::Aspect, Expr::value(Value::Int(None)))
.to_owned();
assert_eq!(
query.to_string(MysqlQueryBuilder),
r#"UPDATE `glyph` SET `aspect` = NULL"#
);
assert_eq!(
query.to_string(PostgresQueryBuilder),
r#"UPDATE "glyph" SET "aspect" = NULL"#
);
assert_eq!(
query.to_string(SqliteQueryBuilder),
r#"UPDATE "glyph" SET "aspect" = NULL"#
);Sourcepub fn limit(&mut self, limit: u64) -> &mut UpdateStatement
pub fn limit(&mut self, limit: u64) -> &mut UpdateStatement
Limit number of updated rows.
Sourcepub fn returning(&mut self, returning: ReturningClause) -> &mut UpdateStatement
pub fn returning(&mut self, returning: ReturningClause) -> &mut UpdateStatement
RETURNING expressions.
Examples
use sea_query::{audit::*, tests_cfg::*, *};
let query = Query::update()
.table(Glyph::Table)
.value(Glyph::Aspect, 2.1345)
.value(Glyph::Image, "235m")
.returning(Query::returning().columns([Glyph::Id]))
.to_owned();
assert_eq!(
query.to_string(MysqlQueryBuilder),
r#"UPDATE `glyph` SET `aspect` = 2.1345, `image` = '235m'"#
);
assert_eq!(
query.to_string(PostgresQueryBuilder),
r#"UPDATE "glyph" SET "aspect" = 2.1345, "image" = '235m' RETURNING "id""#
);
assert_eq!(
query.to_string(SqliteQueryBuilder),
r#"UPDATE "glyph" SET "aspect" = 2.1345, "image" = '235m' RETURNING "id""#
);
assert_eq!(
query.audit().unwrap().updated_tables(),
[Glyph::Table.into_iden()]
);
assert_eq!(
query.audit().unwrap().selected_tables(),
[Glyph::Table.into_iden()]
);Sourcepub fn returning_col<C>(&mut self, col: C) -> &mut UpdateStatementwhere
C: IntoColumnRef,
pub fn returning_col<C>(&mut self, col: C) -> &mut UpdateStatementwhere
C: IntoColumnRef,
RETURNING expressions for a column.
Examples
use sea_query::{tests_cfg::*, *};
let query = Query::update()
.table(Glyph::Table)
.table(Glyph::Table)
.value(Glyph::Aspect, 2.1345)
.value(Glyph::Image, "235m")
.returning_col(Glyph::Id)
.to_owned();
assert_eq!(
query.to_string(MysqlQueryBuilder),
r#"UPDATE `glyph` SET `aspect` = 2.1345, `image` = '235m'"#
);
assert_eq!(
query.to_string(PostgresQueryBuilder),
r#"UPDATE "glyph" SET "aspect" = 2.1345, "image" = '235m' RETURNING "id""#
);
assert_eq!(
query.to_string(SqliteQueryBuilder),
r#"UPDATE "glyph" SET "aspect" = 2.1345, "image" = '235m' RETURNING "id""#
);Sourcepub fn returning_all(&mut self) -> &mut UpdateStatement
pub fn returning_all(&mut self) -> &mut UpdateStatement
RETURNING expressions all columns.
Examples
use sea_query::{tests_cfg::*, *};
let query = Query::update()
.table(Glyph::Table)
.table(Glyph::Table)
.value(Glyph::Aspect, 2.1345)
.value(Glyph::Image, "235m")
.returning_all()
.to_owned();
assert_eq!(
query.to_string(MysqlQueryBuilder),
r#"UPDATE `glyph` SET `aspect` = 2.1345, `image` = '235m'"#
);
assert_eq!(
query.to_string(PostgresQueryBuilder),
r#"UPDATE "glyph" SET "aspect" = 2.1345, "image" = '235m' RETURNING *"#
);
assert_eq!(
query.to_string(SqliteQueryBuilder),
r#"UPDATE "glyph" SET "aspect" = 2.1345, "image" = '235m' RETURNING *"#
);Sourcepub fn with(self, clause: WithClause) -> WithQuery
pub fn with(self, clause: WithClause) -> WithQuery
Create a WithQuery by specifying a WithClause to execute this query with.
Examples
use sea_query::{IntoCondition, IntoIden, audit::*, tests_cfg::*, *};
let select = SelectStatement::new()
.columns([Glyph::Id])
.from(Glyph::Table)
.and_where(Expr::col(Glyph::Image).like("0%"))
.to_owned();
let cte = CommonTableExpression::new()
.query(select)
.column(Glyph::Id)
.table_name("cte")
.to_owned();
let with_clause = WithClause::new().cte(cte).to_owned();
let update = UpdateStatement::new()
.table(Glyph::Table)
.and_where(Expr::col(Glyph::Id).in_subquery(SelectStatement::new().column(Glyph::Id).from("cte").to_owned()))
.value(Glyph::Aspect, Expr::cust("60 * 24 * 24"))
.to_owned();
let query = update.with(with_clause);
assert_eq!(
query.to_string(MysqlQueryBuilder),
r#"WITH `cte` (`id`) AS (SELECT `id` FROM `glyph` WHERE `image` LIKE '0%') UPDATE `glyph` SET `aspect` = 60 * 24 * 24 WHERE `id` IN (SELECT `id` FROM `cte`)"#
);
assert_eq!(
query.to_string(PostgresQueryBuilder),
r#"WITH "cte" ("id") AS (SELECT "id" FROM "glyph" WHERE "image" LIKE '0%') UPDATE "glyph" SET "aspect" = 60 * 24 * 24 WHERE "id" IN (SELECT "id" FROM "cte")"#
);
assert_eq!(
query.to_string(SqliteQueryBuilder),
r#"WITH "cte" ("id") AS (SELECT "id" FROM "glyph" WHERE "image" LIKE '0%') UPDATE "glyph" SET "aspect" = 60 * 24 * 24 WHERE "id" IN (SELECT "id" FROM "cte")"#
);
assert_eq!(
query.audit_unwrap().updated_tables(),
[Glyph::Table.into_iden()]
);
assert_eq!(
query.audit_unwrap().selected_tables(),
[Glyph::Table.into_iden()]
);Sourcepub fn with_cte<C>(&mut self, clause: C) -> &mut UpdateStatementwhere
C: Into<WithClause>,
pub fn with_cte<C>(&mut self, clause: C) -> &mut UpdateStatementwhere
C: Into<WithClause>,
Create a Common Table Expression by specifying a CommonTableExpression or WithClause to execute this query with.
Examples
use sea_query::{IntoCondition, IntoIden, audit::*, tests_cfg::*, *};
let select = SelectStatement::new()
.columns([Glyph::Id])
.from(Glyph::Table)
.and_where(Expr::col(Glyph::Image).like("0%"))
.to_owned();
let cte = CommonTableExpression::new()
.query(select)
.column(Glyph::Id)
.table_name("cte")
.to_owned();
let with_clause = WithClause::new().cte(cte).to_owned();
let query = UpdateStatement::new()
.table(Glyph::Table)
.and_where(Expr::col(Glyph::Id).in_subquery(SelectStatement::new().column(Glyph::Id).from("cte").to_owned()))
.value(Glyph::Aspect, Expr::cust("60 * 24 * 24"))
.with_cte(with_clause)
.to_owned();
assert_eq!(
query.to_string(MysqlQueryBuilder),
r#"WITH `cte` (`id`) AS (SELECT `id` FROM `glyph` WHERE `image` LIKE '0%') UPDATE `glyph` SET `aspect` = 60 * 24 * 24 WHERE `id` IN (SELECT `id` FROM `cte`)"#
);
assert_eq!(
query.to_string(PostgresQueryBuilder),
r#"WITH "cte" ("id") AS (SELECT "id" FROM "glyph" WHERE "image" LIKE '0%') UPDATE "glyph" SET "aspect" = 60 * 24 * 24 WHERE "id" IN (SELECT "id" FROM "cte")"#
);
assert_eq!(
query.to_string(SqliteQueryBuilder),
r#"WITH "cte" ("id") AS (SELECT "id" FROM "glyph" WHERE "image" LIKE '0%') UPDATE "glyph" SET "aspect" = 60 * 24 * 24 WHERE "id" IN (SELECT "id" FROM "cte")"#
);
assert_eq!(
query.audit_unwrap().updated_tables(),
[Glyph::Table.into_iden()]
);
assert_eq!(
query.audit_unwrap().selected_tables(),
[Glyph::Table.into_iden()]
);Sourcepub fn get_values(&self) -> &[(DynIden, Box<Expr>)]
pub fn get_values(&self) -> &[(DynIden, Box<Expr>)]
Get column values
Sourceimpl UpdateStatement
impl UpdateStatement
Sourcepub fn build_collect_any_into(
&self,
query_builder: &impl QueryBuilder,
sql: &mut impl SqlWriter,
)
pub fn build_collect_any_into( &self, query_builder: &impl QueryBuilder, sql: &mut impl SqlWriter, )
Sourcepub fn build_any(&self, query_builder: &impl QueryBuilder) -> (String, Values)
pub fn build_any(&self, query_builder: &impl QueryBuilder) -> (String, Values)
Sourcepub fn build_collect_any(
&self,
query_builder: &impl QueryBuilder,
sql: &mut impl SqlWriter,
) -> String
pub fn build_collect_any( &self, query_builder: &impl QueryBuilder, sql: &mut impl SqlWriter, ) -> String
Sourceimpl UpdateStatement
impl UpdateStatement
Sourcepub fn build_collect_into<T>(&self, query_builder: T, sql: &mut impl SqlWriter)where
T: QueryBuilder,
pub fn build_collect_into<T>(&self, query_builder: T, sql: &mut impl SqlWriter)where
T: QueryBuilder,
Sourcepub fn build_collect<T>(
&self,
query_builder: T,
sql: &mut impl SqlWriter,
) -> Stringwhere
T: QueryBuilder,
pub fn build_collect<T>(
&self,
query_builder: T,
sql: &mut impl SqlWriter,
) -> Stringwhere
T: QueryBuilder,
Sourcepub fn build<T>(&self, query_builder: T) -> (String, Values)where
T: QueryBuilder,
pub fn build<T>(&self, query_builder: T) -> (String, Values)where
T: QueryBuilder,
Sourcepub fn to_string<T>(&self, query_builder: T) -> Stringwhere
T: QueryBuilder,
pub fn to_string<T>(&self, query_builder: T) -> Stringwhere
T: QueryBuilder,
Sourceimpl UpdateStatement
impl UpdateStatement
Sourcepub fn add_order_by(&mut self, order: OrderExpr) -> &mut UpdateStatement
pub fn add_order_by(&mut self, order: OrderExpr) -> &mut UpdateStatement
Sourcepub fn clear_order_by(&mut self) -> &mut UpdateStatement
pub fn clear_order_by(&mut self) -> &mut UpdateStatement
Sourcepub fn order_by<T>(&mut self, col: T, order: Order) -> &mut UpdateStatementwhere
T: IntoColumnRef,
pub fn order_by<T>(&mut self, col: T, order: Order) -> &mut UpdateStatementwhere
T: IntoColumnRef,
Sourcepub fn order_by_expr(
&mut self,
expr: Expr,
order: Order,
) -> &mut UpdateStatement
pub fn order_by_expr( &mut self, expr: Expr, order: Order, ) -> &mut UpdateStatement
Sourcepub fn order_by_customs<I, T>(&mut self, cols: I) -> &mut UpdateStatement
pub fn order_by_customs<I, T>(&mut self, cols: I) -> &mut UpdateStatement
Sourcepub fn order_by_columns<I, T>(&mut self, cols: I) -> &mut UpdateStatement
pub fn order_by_columns<I, T>(&mut self, cols: I) -> &mut UpdateStatement
Sourcepub fn order_by_with_nulls<T>(
&mut self,
col: T,
order: Order,
nulls: NullOrdering,
) -> &mut UpdateStatementwhere
T: IntoColumnRef,
pub fn order_by_with_nulls<T>(
&mut self,
col: T,
order: Order,
nulls: NullOrdering,
) -> &mut UpdateStatementwhere
T: IntoColumnRef,
Sourcepub fn order_by_expr_with_nulls(
&mut self,
expr: Expr,
order: Order,
nulls: NullOrdering,
) -> &mut UpdateStatement
pub fn order_by_expr_with_nulls( &mut self, expr: Expr, order: Order, nulls: NullOrdering, ) -> &mut UpdateStatement
Sourcepub fn order_by_customs_with_nulls<I, T>(
&mut self,
cols: I,
) -> &mut UpdateStatement
pub fn order_by_customs_with_nulls<I, T>( &mut self, cols: I, ) -> &mut UpdateStatement
Sourcepub fn order_by_columns_with_nulls<I, T>(
&mut self,
cols: I,
) -> &mut UpdateStatement
pub fn order_by_columns_with_nulls<I, T>( &mut self, cols: I, ) -> &mut UpdateStatement
Sourceimpl UpdateStatement
impl UpdateStatement
Sourcepub fn and_or_where(
&mut self,
condition: LogicalChainOper,
) -> &mut UpdateStatement
pub fn and_or_where( &mut self, condition: LogicalChainOper, ) -> &mut UpdateStatement
Sourcepub fn cond_where<C>(&mut self, condition: C) -> &mut UpdateStatementwhere
C: IntoCondition,
pub fn cond_where<C>(&mut self, condition: C) -> &mut UpdateStatementwhere
C: IntoCondition,
Sourcepub fn and_where_option(&mut self, other: Option<Expr>) -> &mut UpdateStatement
pub fn and_where_option(&mut self, other: Option<Expr>) -> &mut UpdateStatement
Sourcepub fn and_where(&mut self, other: Expr) -> &mut UpdateStatement
pub fn and_where(&mut self, other: Expr) -> &mut UpdateStatement